@@ -1,6 +1,6 @@
 import {display, undisplay} from "@bokehjs/core/dom"
 import {sum} from "@bokehjs/core/util/arrayable"
-import {isArray, isBoolean, isString, isNumber} from "@bokehjs/core/util/types"
+import {isArray, isBoolean, isFunction, isString, isNumber} from "@bokehjs/core/util/types"
 import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import type {StyleSheetLike} from "@bokehjs/core/dom"
 import {div} from "@bokehjs/core/dom"
@@ -520,7 +520,7 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   override invalidate_render(): void {
-    this.tabulator.destroy()
+    this.tabulator?.destroy()
     this.tabulator = null
     this.rerender_()
   }
@@ -542,7 +542,7 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   get is_drawing(): boolean {
-    return this._building || this._redrawing || !this.root.has_finished()
+    return this._building || this._redrawing || !this.has_finished()
   }
 
   override after_layout(): void {
@@ -571,7 +571,7 @@ export class DataTabulatorView extends HTMLBoxView {
     }
     this.redraw(true, true)
     this.restore_scroll()
-    this.recompute_page_size()
+    requestAnimationFrame(() => this.recompute_page_size())
   }
 
   override stylesheets(): StyleSheetLike[] {
@@ -585,10 +585,13 @@ export class DataTabulatorView extends HTMLBoxView {
     }
   }
 
+  override remove(): void {
+    this.tabulator?.destroy()
+    super.remove()
+  }
+
   override render(): void {
-    if (this.tabulator != null) {
-      this.tabulator.destroy()
-    }
+    this.tabulator?.destroy()
     super.render()
     this._initializing = true
     this._building = true
@@ -720,11 +723,11 @@ export class DataTabulatorView extends HTMLBoxView {
       if (initializing) {
         this._resize_redraw()
       }
-    }, () => this.root.has_finished() && [...this._initialized_stylesheets.values()].every(v => v))
+    }, () => this.has_finished() && [...this._initialized_stylesheets.values()].every(v => v))
   }
 
   recompute_page_size(): void {
-    if (!this.model.pagination || this.model.page_size !== null || this._automatic_page_size) {
+    if (!this.model.pagination || (this.model.page_size !== null && !this._automatic_page_size) || this._initializing || !this.tabulator) {
       return
     }
     this._automatic_page_size = true
@@ -753,7 +756,7 @@ export class DataTabulatorView extends HTMLBoxView {
         const remaining = table_height - height
         page_size += Math.floor(remaining / Math.min(...heights))
         if (responsive) {
-          page_size -= 2
+          page_size -= 1
         }
       }
       this._updating_page_size = true
@@ -926,7 +929,7 @@ export class DataTabulatorView extends HTMLBoxView {
         this._update_children()
         this.resize_table()
       }
-    }, () => this.root.has_finished())
+    }, () => this.has_finished())
   }
 
   resize_table(): void {
@@ -1117,7 +1120,14 @@ export class DataTabulatorView extends HTMLBoxView {
         }
       }
       tab_column.visible = (tab_column.visible != false && !this.model.hidden_columns.includes(column.field))
-      tab_column.editable = () => (this.model.editable && (editor.default_view != null))
+      const originalEditable = tab_column.editable
+      if (isFunction(originalEditable)) {
+        tab_column.editable = (cell: any) => (this.model.editable && (editor.default_view != null) && originalEditable(cell))
+      } else if (isBoolean(originalEditable)) {
+        tab_column.editable = () => (this.model.editable && (editor.default_view != null) && originalEditable)
+      } else {
+        tab_column.editable = () => (this.model.editable && (editor.default_view != null))
+      }
       if (tab_column.headerFilter) {
         if (isBoolean(tab_column.headerFilter) && isString(tab_column.editor)) {
           tab_column.headerFilter = tab_column.editor
@@ -1153,7 +1163,7 @@ export class DataTabulatorView extends HTMLBoxView {
       }
       columns.push(button_column)
     }
-    if (this.model.container_popup) {
+    if (this.model.container_popup && (this.model.layout !== "fit_data_stretch")) {
       // We insert an empty last column to ensure select editor is rendered in correct position
       // see: https://github.com/holoviz/panel/issues/7295
       columns.push({width: 1, maxWidth: 1, minWidth: 1, resizable: false, cssClass: "empty", sorter: null})
