@@ -16,8 +16,14 @@ class TrendIndicator(HTMLBox):
     """
 
     description = String()
-    change_formatter = Instance(TickFormatter, default=lambda: NumeralTickFormatter(format='0.00%'))
-    formatter = Instance(TickFormatter, default=lambda: BasicTickFormatter())
+    change_formatter = Instance(
+        TickFormatter,
+        default=lambda: NumeralTickFormatter(format='0.00%')  # type: ignore
+    )
+    formatter = Instance(
+        TickFormatter,
+        default=lambda: BasicTickFormatter()  # type: ignore
+    )
     layout = String()
     source = Instance(ColumnDataSource)
     plot_x = String()
