@@ -9,6 +9,7 @@ import base64
 import struct
 
 from collections.abc import Mapping
+from html import escape
 from io import BytesIO
 from pathlib import PurePath
 from typing import TYPE_CHECKING, Any, ClassVar
@@ -16,8 +17,8 @@ from typing import TYPE_CHECKING, Any, ClassVar
 import param
 
 from ..models import PDF as _BkPDF
-from ..util import isfile, isurl
-from .markup import HTMLBasePane, escape
+from ..util import _descendents, isfile, isurl
+from .markup import HTMLBasePane
 
 if TYPE_CHECKING:
     from bokeh.model import Model
@@ -255,7 +256,7 @@ class Image(ImageBase):
     @classmethod
     def applies(cls, obj: Any) -> float | bool | None:
         precedences = []
-        for img_cls in param.concrete_descendents(ImageBase).values():
+        for img_cls in _descendents(ImageBase, concrete=True):
             if img_cls is Image:
                 continue
             applies = img_cls.applies(obj)
@@ -272,7 +273,7 @@ class Image(ImageBase):
             k: v for k, v in self.param.values().items()
             if k not in ('name', 'object')
         }
-        for img_cls in param.concrete_descendents(ImageBase).values():
+        for img_cls in _descendents(ImageBase, concrete=True):
             if img_cls is not Image and img_cls.applies(obj):
                 return img_cls(obj, **params)._transform_object(obj)
         return {'object': '<img></img>'}
