@@ -9,6 +9,7 @@ import json
 import textwrap
 
 from collections.abc import Mapping
+from html import escape
 from typing import TYPE_CHECKING, Any, ClassVar
 
 import param  # type: ignore
@@ -16,7 +17,7 @@ import param  # type: ignore
 from ..config import config
 from ..io.resources import CDN_DIST
 from ..models.markup import HTML as _BkHTML, JSON as _BkJSON, HTMLStreamEvent
-from ..util import HTML_SANITIZER, escape, prefix_length
+from ..util import HTML_SANITIZER, prefix_length
 from .base import ModelPane
 
 if TYPE_CHECKING:
@@ -348,6 +349,9 @@ class Markdown(HTMLBasePane):
     dedent = param.Boolean(default=True, doc="""
         Whether to dedent common whitespace across all lines.""")
 
+    disable_anchors = param.Boolean(default=False, doc="""
+        Whether to disable automatically adding anchors to headings.""")
+
     disable_math = param.Boolean(default=False, doc="""
         Whether to disable support for MathJax math rendering for
         strings escaped with $$ delimiters.""")
@@ -376,13 +380,13 @@ class Markdown(HTMLBasePane):
     priority: ClassVar[float | bool | None] = None
 
     _rename: ClassVar[Mapping[str, str | None]] = {
-        'hard_line_break': None,
+        'hard_line_break': None, 'disable_anchors': None,
         'dedent': None, 'disable_math': None, 'extensions': None,
         'plugins': None, 'renderer': None, 'renderer_options': None
     }
 
     _rerender_params: ClassVar[list[str]] = [
-        'object', 'dedent', 'extensions', 'css_classes', 'plugins',
+        'object', 'dedent', 'extensions', 'css_classes', 'plugins', 'disable_anchors'
     ]
 
     _target_transforms: ClassVar[Mapping[str, str | None]] = {
@@ -404,7 +408,7 @@ class Markdown(HTMLBasePane):
 
     @classmethod
     @functools.cache
-    def _get_parser(cls, renderer, plugins, hard_line_break, **renderer_options):
+    def _get_parser(cls, renderer, plugins, hard_line_break=False, disable_anchors=True, **renderer_options):
         if renderer == 'markdown':
             return None
         from markdown_it import MarkdownIt
@@ -442,8 +446,10 @@ class Markdown(HTMLBasePane):
         parser = (
             parser
             .enable('strikethrough').enable('table')
-            .use(anchors_plugin, permalink=True).use(deflist_plugin).use(footnote_plugin).use(tasklists_plugin)
+            .use(deflist_plugin).use(footnote_plugin).use(tasklists_plugin)
         )
+        if not disable_anchors:
+            parser = parser.use(anchors_plugin, permalink=True)
         for plugin in plugins:
             parser = parser.use(plugin)
         try:
@@ -473,7 +479,7 @@ class Markdown(HTMLBasePane):
             )
         else:
             parser = self._get_parser(
-                self.renderer, tuple(self.plugins), self.hard_line_break, **self.renderer_options
+                self.renderer, tuple(self.plugins), self.hard_line_break, self.disable_anchors, **self.renderer_options
             )
             try:
                 html = parser.render(obj)
