@@ -10,7 +10,6 @@ import param
 
 from .layout import Column, Row
 from .pane import HoloViews, Markdown
-from .param import Param
 from .util import param_reprs
 from .viewable import Viewer
 from .widgets import Button, Select
@@ -161,9 +160,9 @@ class Pipeline(Viewer):
         Whether to show the header with the title, network diagram,
         and buttons.""")
 
-    next = param.Action(default=lambda x: x.param.trigger('next'))
+    next = param.Event()
 
-    previous = param.Action(default=lambda x: x.param.trigger('previous'))
+    previous = param.Event()
 
     _ignored_refs: ClassVar[tuple[str, ...]] = ('next_parameter', 'ready_parameter')
 
@@ -189,10 +188,10 @@ class Pipeline(Viewer):
         # Declare UI components
         self._progress_sel = hv.streams.Selection1D()
         self._progress_sel.add_subscriber(self._set_stage)
-        self.prev_button = Param(self.param.previous).layout[0]
+        self.prev_button = Button.from_param(self.param.previous)
         self.prev_button.width = 125
         self.prev_selector = Select(width=125)
-        self.next_button = Param(self.param.next).layout[0]
+        self.next_button = Button.from_param(self.param.next)
         self.next_button.width = 125
         self.next_selector = Select(width=125)
         self.prev_button.disabled = True
@@ -239,7 +238,7 @@ class Pipeline(Viewer):
             else:
                 cls_name = stage.__name__
             params = ', '.join(param_reprs(stage))
-            repr_str += '\n    [%d] %s: %s(%s)' % (i, name, cls_name, params)
+            repr_str += f'\n    [{i}] {name}: {cls_name}({params})'
         return repr_str
 
     def __str__(self):
@@ -387,7 +386,7 @@ class Pipeline(Viewer):
             self.next_button.disabled = True
         else:
             ready = kwargs.get('ready_parameter', self.ready_parameter)
-            disabled = (not getattr(stage, ready)) if ready in stage.param else False
+            disabled = (not getattr(self._state, ready)) if ready in self._state.param else False
             self.next_button.disabled = disabled
 
     def _get_error_button(self, e):
@@ -410,7 +409,8 @@ class Pipeline(Viewer):
         self._stage = self._next_stage
         self.stage.loading = True
         try:
-            self.stage[0] = self._init_stage()
+            if self._stage is not None:
+                self.stage[0] = self._init_stage()
         except Exception as e:
             self._error = self._stage
             self._stage = prev_stage
@@ -539,8 +539,8 @@ class Pipeline(Viewer):
         """
         Adds a new, named stage to the Pipeline.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         name: str
           A string name for the Pipeline stage
         stage: param.Parameterized
@@ -574,8 +574,8 @@ class Pipeline(Viewer):
         the default linear flow. The graph should be defined as an
         adjacency mapping.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         graph: dict
           Dictionary declaring the relationship between different
           pipeline stages. Should map from a single stage name to
